# Jesse Brault: Full-Stack Software Engineer

![Jesse Brault Hero Photograph](images/JesseBraultHeaderNoTextMin.jpg)

**Welcome! I am a full-stack software engineer currently looking for work in the United States, particularly in the New
York City area, or in the Upper Midwest (Madison, Milwaukee, Twin Cities, Chicago). If you would like my résumé, please
message me.**

I began my career as a classically-trained conductor and composer, and am transitioning to software engineering 
full-time. I love programming, learning new languages and frameworks, and developing interesting and exciting projects. 
I am finishing computer-science studies at the University of Wisconsin-Madison.

My programming interests lie in programming languages themselves (including grammars, lexers, parsers, ASTs, 
compilation, transpilation, etc.), web and app development (full-stack, including Spring, Node, and React), programming
tools and plugins (Gradle and IntelliJ plugins), and functional programming.

Overall, I aim to be highly versatile and adept at adopting new technologies. I seek every day to hone my craft and
become a better developer. I enjoy the logical and linguistic nature of software, and that sweet feeling When Things 
Just Work™️. I also enjoy the collaborative process of bringing new ideas and designs to life.

## Current Projects

*Note: some projects are hosted here, others still at GitHub. I intend to move all personal projects here.*

### Full Stack
- **Meals Made Easy**: A full-stack remake of an earlier app, using a Java/Spring Boot backend and React/Vite frontend. 
  2024–present. [Frontend](https://git.jessebrault.com/jessebrault/meals-made-easy-app) | 
  [Backend](https://git.jessebrault.com/jessebrault/meals-made-easy-api)

### JVM: Java and Groovy
- [**groowt**, or **Groovy Web Tools**](https://git.jessebrault.com/jessebrault/groowt): A set of libraries, CLI tools, 
  and Gradle plugins written mostly in Java for facilitating web-development in Groovy, emphasizing the 
  model-view-controller paradigm. Includes a custom templating language inspired by ReactJS, with a compiler developed
  with the ANTLR parser generator. 2024–present.
- [**ssg**, or **Static Site Generator**](https://github.com/JesseBrault0709/ssg): A highly-extensible CLI application 
  written entirely in Groovy for statically generating websites from text files and other input. I created this out of a
  need for a static site generator in which I could embed Groovy without all the hassle of a full-size server-oriented 
  framework such as Grails. So far, I am using it for all my personal sites, and it has also been used outside of my 
  own projects. 2023–present.
- [**jbarchiva**](https://github.com/JesseBrault0709/jbarchiva): A Gradle plugin to facilitate easy access to my 
  personal Maven repository at [archiva.jessebrault.com](https://archiva.jessebrault.com/). 2022-2024.

### JavaScript/TypeScript
- [**jbci**, or **Jesse Brault Continuous Integration**](https://github.com/JesseBrault0709/jbci): A CI program written 
  in TypeScript which listens to GitHub webhooks and then executes pre-configured shell scripts based on the webhook
  payload, mainly used to update my websites by simple pushes to my various Git repositories.
- [**jb-api**](https://github.com/JesseBrault0709/jb-api): A very simple utility backend written in TypeScript for my 
  personal websites. Currently its only function is to recieve and handle mail requests (such as from a contact form).
  
### Web Sites
- [Personal Website](https://git.jessebrault.com/jessebrault/jb-ssg-site): My personal website where I store information 
  about my career as both a classical musician and a developer. <a href="https://jessebrault.com/" target="_blank">Visit
  site.</a>
- [Red Dog Ensemble](https://github.com/JesseBrault0709/reddog): A web site for a contemporary classical music ensemble 
  I co-founded in New York City. <a href="https://reddogensemble.com/" target="_blank">Visit site.</a>

### Rust
- [**Deimos Lang**](https://git.jessebrault.com/jessebrault/deimos-lang): A programming language I am designing and
  implementing with the intention of allowing strongly-typed scripting that is both fast and simple enough for basic
  "glue" tasks such as querying APIs and running local bash commands based on the results. Includes a virtual machine
  implementation which I think of as a very miniature JVM. 2024–present.

## Past Projects

- [**Meals Made Easy**](https://github.com/JesseBrault0709/MealsMadeEasy): A fully-functioning meal-planning web-app 
  developed during my time in _Co.Lab | You Belong in Tech_. I worked closely with a product manager and designer to 
  make the project come alive! It is built with TypeScript, React, and SCSS.

## Languages

<div>
  <img src="images/javaWithColor.svg" alt="Java" width="48" height="92">
  <img src="images/groovy.svg" alt="Groovy" width="72" height="48">
  <img src="images/kotlin.svg" alt="Kotlin" width="48" height="48">
  <img src="images/jsWithColor.svg" alt="JavaScript" width="48" height="48">
  <img src="images/tsWithColor.svg" alt="TypeScript" width="48" height="48">
</div>

I am most fluent with Java, Groovy and Typescript. I am also fluent with standard web technologies such as HTML5, CSS, 
and sass. I have also dabbled in Rust, Ruby, Lua, and C.

## Coursework at UW-Madison

- **CS 354** *Machine Organization and Programming*: Low-level programming with C and assembly.
- **CS 400** *Programming III*: General purpose programming with Java, covering important tree and graph algorithms.
- **CS 506** *Software Engineering*: Built a full-stack app *Task Tango* with a team of six developers following the
  agile/scrum methods. Consisted of a Java/Spring Boot backend, and JavaScript/React frontend. Everything containerized
  and ultimately deployed to a department virtual machine.
- **CS 536** *Introduction to Programming Languages and Compilers*: Working to build a compiler for a toy language 
  entitled *Bach* targeting the MIPS architecture, using Java as a host language. Learning about topics related to
  scanners, parsers, optimization, and code generation.

## Frameworks, Libraries, Tools, and Technologies

### JVM: Java and Groovy

#### Frameworks
- Spring, Spring Boot

#### Testing
- JUnit Jupiter, JUnit 4

#### Tools
- Gradle
- IntelliJ Idea

### JavaScript/TypeScript

#### Front-End
- React
- Redux
- Vite

#### Back-End
- Express
- GraphQL
- Prisma
- fp-ts (my favorite TS library!)

#### Testing
- Jest

#### Tools
- Npm
- Gulp
- VSCode

### Containerization
- Docker

### Databases
- MySQL
- SQLite

### Documentation
- Asciidoc
- Markdown

## Other Skills

- Server Administration: I run my own Ubuntu-based virtual private server at digitalocean.com, where I host a variety of
  services and web sites, such as my personal website, an Apache Archiva instance, and a Gitea instance (where you are 
  now!). Tasks I often do include:
  - Package administration
  - Continuous integration
  - Securing the environment
  - Using `ssh` and `sftp`
  - Configuring `apache` for serving static content as well as reverse-proxying to various services
  - Using and configuring Docker and various Docker containers for services and websites.
- Web and App Design: I have some design experience for both web sites and apps. Particularly, I have an as-of-yet 
  unfinished design at Figma for *The Pantry App*, which can be viewed 
  [here](https://www.figma.com/file/VKrirPQi2FneCPaP3XdPzn/Pantry-App-Design?node-id=0%3A1&t=eSnEntKpbxK7LEJG-1). I have
  additionally done UX testing with Maze.
- (Human) Languages:
  - English: native speaker.
  - German: B1.
  - Spanish: basic.
- Photography/Videography: experience with Adobe Photoshop, Lightroom, Premiere, and Creative Cloud.

## Education

- Professional Captsone Certificate in Computer Science. University of Wisconsin-Madison. 2024–2025 (expected graduation
  May 2025).
- Master of Music, orchestral conducting. The Juilliard School, 2018.
- Bachelor of Music, *summa cum laude*, music theory and composition. St. Olaf College, 2013. GPA 3.91.
  
## Contact

- [LinkedIn](https://www.linkedin.com/in/jessebrault0709/)
- [Email](mailto:jbrault@mac.com)
- [Personal Website](https://jessebrault.com/)
- [GitHub Profile](https://github.com/JesseBrault0709)
